@@ -5,7 +5,7 @@ from pathlib import Path
 from jinja2 import Environment, PackageLoader
 import click
 from ploomber import __version__
-from ploomber.entry import entry as entry_module
+from ploomber import entry as entry_module
 from ploomber.spec.DAGSpec import DAGSpec
 
 try:
@@ -40,7 +40,7 @@ def new():
 
 @cli.command()
 def add():
-    """Add tasks declared in pipeline.yaml whose source code files do not exist
+    """Create soource files tasks registered in pipeline.yaml
     """
     _add()
 
@@ -153,15 +153,54 @@ def _new():
     click.echo('Check out {} to get started'.format(path_to_readme))
 
 
+def cmd_router():
+    cmd_name = sys.argv[1]
+
+    custom = {
+        'entry': entry_module.entry._main,
+        'plot': entry_module.plot.main,
+        'task': entry_module.task.main,
+        'report': entry_module.report.main,
+    }
+
+    if cmd_name in custom:
+        # NOTE: we don't use the argument here, it is parsed by _main
+        # pop the second element ('entry') to make the CLI behave as expected
+        sys.argv.pop(1)
+        # Add the current working directory, this is done automatically when
+        # calling "python -m ploomber.entry" but not here ("ploomber entry")
+        sys.path.append('')
+        fn = custom[cmd_name]
+        fn()
+    else:
+        cli()
+
+
+# the commands below are handled by the router, thy are just here so they
+# show up when doing ploomber --help
 @cli.command()
-@click.argument('entry_point')
-def entry(entry_point):
-    """Call an entry point (pipeline.yaml or dotted path to factory)
+def entry():
+    """Call entry points
     """
-    # NOTE: we don't use the argument here, it is parsed by _main
-    # pop the second element ('entry') to make the CLI behave as expected
-    sys.argv.pop(1)
-    # Add the current working directory, this is done automatically when
-    # calling "python -m ploomber.entry" but not here ("ploomber entry")
-    sys.path.append('')
-    entry_module._main()
+    pass
+
+
+@cli.command()
+def plot():
+    """Plot pipeline
+    """
+    pass
+
+
+@cli.command()
+def task():
+    """Interact with specific tasks
+    """
+    pass
+
+
+@cli.command()
+def report():
+    """Make a pipeline report
+    """
+    pass
