@@ -1,4 +1,5 @@
 from jinja2 import Environment, meta
+from jinja2.nodes import Assign
 
 
 def get_tags_in_str(s):
@@ -13,3 +14,10 @@ def get_tags_in_str(s):
     # this accepts None and does not break!
     ast = env.parse(s)
     return meta.find_undeclared_variables(ast)
+
+
+def get_defined_variables(s):
+    env = Environment()
+    ast = env.parse(s)
+    return {n.target.name: n.node.as_const()
+            for n in ast.find_all(Assign)}
